
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'translatable/translatable-block', {
        apiVersion: 2,
        title: __( 'Translatable Block', 'translatable' ),
        description: __( 'This block\'s controls can be translated using native WordPress functions' , 'translatable' ),
        icon: 'translation',
        category: 'widgets',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            image: {
                type: 'object',
                default: {id: 0, url: 'https://images.unsplash.com/photo-1613909207039-6b173b755cc1?ixid=MnwyMDkyMnwwfDF8c2VhcmNofDV8fGRlc2lnbmVyfGVufDB8fHx8MTYzMjg2OTMwMA&ixlib=rb-1.2.1q=85&fm=jpg&crop=faces&cs=srgb&w=800&h=1000&fit=crop', size: '', svg: '', alt: '...'},
            },
            title: {
                type: 'string',
                default: `About Me`,
            },
            description: {
                type: 'string',
                default: __( 'Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Curabitur ac sagittis neque, vel egestas est.', 'translatable' ),
            },
            more_link: {
                type: 'object',
                default: {post_id: 0, url: '#', title: '', 'post_type': null},
            },
            more_label: {
                type: 'string',
                default: __( 'Full Story', 'translatable' ),
            }
        },
        example: { attributes: { image: {id: 0, url: 'https://images.unsplash.com/photo-1613909207039-6b173b755cc1?ixid=MnwyMDkyMnwwfDF8c2VhcmNofDV8fGRlc2lnbmVyfGVufDB8fHx8MTYzMjg2OTMwMA&ixlib=rb-1.2.1q=85&fm=jpg&crop=faces&cs=srgb&w=800&h=1000&fit=crop', size: '', svg: '', alt: '...'}, title: __( 'About Me', 'translatable' ), description: __( 'Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus pulvinar faucibus neque, nec rhoncus nunc ultrices sit amet. Curabitur ac sagittis neque, vel egestas est.', 'translatable' ), more_link: {post_id: 0, url: '#', title: '', 'post_type': null}, more_label: __( 'Full Story', 'translatable' ) } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'fancy-block pb-5 pt-5' });
            const setAttributes = props.setAttributes; 
            
            props.image = useSelect(function( select ) {
                return {
                    image: props.attributes.image.id ? select('core').getMedia(props.attributes.image.id) : undefined
                };
            }, [props.attributes.image] ).image;
            
            
            const innerBlocksProps = null;
            
            
            return el(Fragment, {}, [
                el('section', { ...blockProps }, [' ', ' ', el('div', { className: 'container pb-5 pt-5' }, [' ', ' ', el('div', { className: 'align-items-center gy-4 row' }, [' ', el('div', { className: 'col-lg-4' }, [' ', props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'img-fluid rounded-1 shadow-sm w-100' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), className: 'img-fluid rounded-1 shadow-sm w-100 ' + (props.attributes.image.id ? ('wp-image-' + props.attributes.image.id) : ''), alt: propOrDefault( props.attributes.image?.alt, 'image', 'alt' ), width: '600', height: '650' }), ' ']), ' ', el('div', { className: 'col-lg-8' }, [' ', el(RichText, { tagName: 'h3', className: 'fw-bold h1 mb-3 text-capitalize text-primary', value: propOrDefault( props.attributes.title, 'title' ), onChange: function(val) { setAttributes( {title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), ' ', el(RichText, { tagName: 'p', className: 'mb-4', value: propOrDefault( props.attributes.description, 'description' ), onChange: function(val) { setAttributes( {description: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), ' ', el('div', { className: 'g-3 mb-4 row' }, [' ', ' ', el('div', { className: 'col-md-4' }, [' ', ' ', el('div', { className: 'bg-light h-100 p-4 rounded-1 shadow-sm' }, [' ', el('h4', { className: 'display-4 fw-bold text-primary' }, __( '10+', 'translatable' )), ' ', el('p', { className: 'fw-bold h6 text-secondary' }, __( 'Years of Experience', 'translatable' )), ' ']), ' ', ' ']), ' ', el('div', { className: 'col-md-4' }, [' ', ' ', el('div', { className: 'bg-light h-100 p-4 rounded-1 shadow-sm' }, [' ', ' ', el('h4', { className: 'display-4 fw-bold text-primary' }, __( '200+', 'translatable' )), ' ', el('p', { className: 'fw-bold h6 text-secondary' }, __( 'Projects Completed', 'translatable' )), ' ', ' ']), ' ', ' ']), ' ', el('div', { className: 'col-md-4' }, [' ', ' ', el('div', { className: 'bg-light h-100 p-4 rounded-1 shadow-sm' }, [' ', ' ', el('h4', { className: 'display-4 fw-bold text-primary' }, __( '12', 'translatable' )), ' ', el('p', { className: 'fw-bold h6 text-secondary' }, __( 'Industry Awards', 'translatable' )), ' ', ' ']), ' ', ' ']), ' ', ' ']), el(RichText, { tagName: 'a', href: propOrDefault( props.attributes.more_link.url, 'more_link', 'url' ), className: 'btn btn-primary pe-4 ps-4', onClick: function(e) { e.preventDefault(); }, value: propOrDefault( props.attributes.more_label, 'more_label' ), onChange: function(val) { setAttributes( {more_label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), ' ']), ' ']), ' ']), ' ', ' ']),
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('image', setAttributes, props, 'medium', false, __( 'Block image', 'translatable' ), __( 'Add the block image.', 'translatable' ) ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties', 'translatable' )
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( 'Enter the block title.', 'translatable' ),
                                        label: __( 'Title', 'translatable' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.description,
                                        help: __( 'Enter the description text.', 'translatable' ),
                                        label: __( 'Description', 'translatable' ),
                                        onChange: function(val) { setAttributes({description: val}) },
                                        type: 'text'
                                    }),
                                    pgUrlControl('more_link', setAttributes, props, __( '“More” button link', 'translatable' ), __( 'Enter the link for the “more” button.', 'translatable' ), null ),
                                    el(TextControl, {
                                        value: props.attributes.more_label,
                                        help: __( 'Enter the label for the “more” button', 'translatable' ),
                                        label: __( '“More” button label', 'translatable' ),
                                        onChange: function(val) { setAttributes({more_label: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'fancy-block pb-5 pt-5' });
            return el('section', { ...blockProps }, [' ', ' ', el('div', { className: 'container pb-5 pt-5' }, [' ', ' ', el('div', { className: 'align-items-center gy-4 row' }, [' ', el('div', { className: 'col-lg-4' }, [' ', props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'img-fluid rounded-1 shadow-sm w-100' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), className: 'img-fluid rounded-1 shadow-sm w-100 ' + (props.attributes.image.id ? ('wp-image-' + props.attributes.image.id) : ''), alt: propOrDefault( props.attributes.image?.alt, 'image', 'alt' ), width: '600', height: '650' }), ' ']), ' ', el('div', { className: 'col-lg-8' }, [' ', el(RichText.Content, { tagName: 'h3', className: 'fw-bold h1 mb-3 text-capitalize text-primary', value: propOrDefault( props.attributes.title, 'title' ) }), ' ', el(RichText.Content, { tagName: 'p', className: 'mb-4', value: propOrDefault( props.attributes.description, 'description' ) }), ' ', el('div', { className: 'g-3 mb-4 row' }, [' ', ' ', el('div', { className: 'col-md-4' }, [' ', ' ', el('div', { className: 'bg-light h-100 p-4 rounded-1 shadow-sm' }, [' ', el('h4', { className: 'display-4 fw-bold text-primary' }, __( '10+', 'translatable' )), ' ', el('p', { className: 'fw-bold h6 text-secondary' }, __( 'Years of Experience', 'translatable' )), ' ']), ' ', ' ']), ' ', el('div', { className: 'col-md-4' }, [' ', ' ', el('div', { className: 'bg-light h-100 p-4 rounded-1 shadow-sm' }, [' ', ' ', el('h4', { className: 'display-4 fw-bold text-primary' }, __( '200+', 'translatable' )), ' ', el('p', { className: 'fw-bold h6 text-secondary' }, __( 'Projects Completed', 'translatable' )), ' ', ' ']), ' ', ' ']), ' ', el('div', { className: 'col-md-4' }, [' ', ' ', el('div', { className: 'bg-light h-100 p-4 rounded-1 shadow-sm' }, [' ', ' ', el('h4', { className: 'display-4 fw-bold text-primary' }, __( '12', 'translatable' )), ' ', el('p', { className: 'fw-bold h6 text-secondary' }, __( 'Industry Awards', 'translatable' )), ' ', ' ']), ' ', ' ']), ' ', ' ']), el(RichText.Content, { tagName: 'a', href: propOrDefault( props.attributes.more_link.url, 'more_link', 'url' ), className: 'btn btn-primary pe-4 ps-4', value: propOrDefault( props.attributes.more_label, 'more_label' ) }), ' ']), ' ']), ' ']), ' ', ' ']);
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
